@@ -1,29 +1,29 @@
 use anyhow::Result;
-use ethers::prelude::*;
+use ethers::{prelude::*, utils::Ganache};
 use std::convert::TryFrom;
 
 #[tokio::main]
 async fn main() -> Result<()> {
+    // fork mainnet
+    let ganache = Ganache::new()
+        .fork("https://mainnet.infura.io/v3/c60b0bb42f8a4c6481ecd229eddaca27")
+        .spawn();
+    let from = ganache.addresses()[0].clone();
     // connect to the network
-    let provider = Provider::<Http>::try_from(
-        "https://mainnet.infura.io/v3/c60b0bb42f8a4c6481ecd229eddaca27",
-    )?;
-
-    // create a wallet and connect it to the provider
-    let wallet = "dcf2cbdd171a21c480aa7f53d77f31bb102282b3ff099c78e3118b37348c72f7"
-        .parse::<LocalWallet>()?;
-    let client = SignerMiddleware::new(provider, wallet);
+    let provider = Provider::<Http>::try_from(ganache.endpoint())
+        .unwrap()
+        .with_sender(from);
 
     // craft the transaction
     let tx = TransactionRequest::new().to("vitalik.eth").value(100_000);
 
     // send it!
-    let receipt = client
+    let receipt = provider
         .send_transaction(tx, None)
         .await?
         .await?
         .ok_or_else(|| anyhow::format_err!("tx dropped from mempool"))?;
-    let tx = client.get_transaction(receipt.transaction_hash).await?;
+    let tx = provider.get_transaction(receipt.transaction_hash).await?;
 
     println!("{}", serde_json::to_string(&tx)?);
     println!("{}", serde_json::to_string(&receipt)?);
